@@ -6,10 +6,11 @@ from .fba_from_reactions import run_the_fba
 from .gapfill_from_reactions_multiple_conditions import gapfill_multiple_media
 from .media import list_media
 from .reactions_to_roles import convert_reactions_to_roles
+from .gapcreate import create_reaction_gaps
 
 # Don't forget to add the imports here so that you can import *
 
 __all__ = [
     'cite_me_please', 'measure_fluxes', 'gapfill_from_roles', 'to_reactions', 'run_the_fba', 'gapfill_multiple_media',
-    'list_media', 'convert_reactions_to_roles'
+    'list_media', 'convert_reactions_to_roles', 'create_reaction_gaps'
 ]
