@@ -24,6 +24,7 @@ fluxes\tGiven a set of reactions that form a model, report the fluxes through th
 to_reactions\tConvert a set of functional roles or feature names to a list of reactions
 gapfill_roles\tGapfill Flux Balance Analysis from a list of functional roles
 multiple_media\tGapfill a set of reactions with multiple media where the organism can/can not grow
+create_gaps\tThe opposite of gapfill: Given a media and a set of reactions, reduce them to the smallest set that can run
 
 reactions_to_roles\tGiven a file with a set of reactions, print the roles that implement those reactions
 
@@ -63,6 +64,8 @@ def run():
         run_the_fba()
     elif sys.argv[1] == 'to_reactions':
         to_reactions()
+    elif sys.argv[1] == 'create_gaps':
+        create_reaction_gaps()
     else:
         sys.stderr.write(f"Sorry. Don't understand {sys.argv[1]}.")
         sys.stderr.write(full_help())
