@@ -160,6 +160,7 @@ def read_reactions(reaction_file, verbose=False):
             r = li.strip()
             if r in modeldata.reactions:
                 reactions2run.add(r)
+    return reactions2run
 
 
 def measure_accuracy(why, growth_media, no_growth_media, reactions, added_reactions,
@@ -194,7 +195,7 @@ def measure_accuracy(why, growth_media, no_growth_media, reactions, added_reacti
     pr = PyFBA.gapfill.calculate_precision_recall(growth_media, no_growth_media, modeldata, reactions, biomass_eqtn)
     acc = PyFBA.gapfill.reaction_minimization.accuracy(pr)
 
-    msg = f"Testing accuracy: {why}"
+    msg = f"Testing accuracy: {why} "
     for t in ['tp', 'fp', 'tn', 'fn']:
         msg += f"{t}: {pr[t]} "
     msg += f"Accuracy: {acc}\n"
@@ -328,6 +329,8 @@ def multiple_gapfill(reactions, positive, negative, min_growth_conditions, close
     :rtype: set[str]
     """
 
+    if close is None:
+        close = list()
     global modeldata
     growth_media = [read_media(m, modeldata=modeldata, verbose=verbose) for m in positive]
     no_growth_media = [read_media(m, modeldata=modeldata, verbose=verbose) for m in negative]
@@ -423,23 +426,24 @@ def multiple_gapfill(reactions, positive, negative, min_growth_conditions, close
     #############################################################################################
 
     log_and_message("Gap filling from CLOSE GENOMES", stderr=verbose)
-    for close_genome in close:
-        # add reactions from roles in close genomes
-        close_reactions = PyFBA.gapfill.suggest_from_roles(close_genome, modeldata.reactions, threshold=0,
-                                                           verbose=verbose)
-        # find the new reactions
-        close_reactions.difference_update(reactions)
-        added_reactions.append((f"close genome: {close_genome}", close_reactions))
-        reactions.update(close_reactions)
-        for r in close_reactions:
-            if r not in reaction_source:
-                reaction_source[r] = f"close genome: {close_genome}"
+    if close:
+        for close_genome in close:
+            # add reactions from roles in close genomes
+            close_reactions = PyFBA.gapfill.suggest_from_roles(close_genome, modeldata.reactions, threshold=0,
+                                                               verbose=verbose)
+            # find the new reactions
+            close_reactions.difference_update(reactions)
+            added_reactions.append((f"close genome: {close_genome}", close_reactions))
+            reactions.update(close_reactions)
+            for r in close_reactions:
+                if r not in reaction_source:
+                    reaction_source[r] = f"close genome: {close_genome}"
 
-        tp = measure_accuracy(f"Close genome: {close_genome}",  growth_media, no_growth_media, reactions,
-                              added_reactions, biomass_eqtn, min_growth_conditions, reaction_source, output, verbose)
-        if tp > max_tp:
-            best_reactions = copy.deepcopy(reactions)
-            max_tp = tp
+            tp = measure_accuracy(f"Close genome: {close_genome}",  growth_media, no_growth_media, reactions,
+                                  added_reactions, biomass_eqtn, min_growth_conditions, reaction_source, output, verbose)
+            if tp > max_tp:
+                best_reactions = copy.deepcopy(reactions)
+                max_tp = tp
 
     #############################################################################################
     #                                        Subsystems                                         #
@@ -516,6 +520,7 @@ def gapfill_multiple_media():
     global modeldata
     modeldata = PyFBA.parse.model_seed.parse_model_seed_data(args.type, verbose=args.verbose)
     reactions = read_reactions(args.reactions, args.verbose)
+    log_and_message(f"Found {len(reactions)} reactions", stderr=args.verbose)
 
     max_tp, best_reactions = multiple_gapfill(reactions, args.positive, args.negative, args.fraction,
                                               args.close_genomes, args.type, args.output, args.verbose)
